@@ -42,6 +42,8 @@ namespace Tomboy
 			Buffer.MarkSet += OnMarkSet;
 			Buffer.InsertText += OnInsertText;
 			Buffer.DeleteRange += OnDeleteRange;
+			
+			Window.Editor.FocusOutEvent += OnEditorFocusOut;
 
 			// FIXME: Needed because we hide on delete event, and
 			// just hide on accelerator key, so we can't use delete
@@ -53,6 +55,16 @@ namespace Tomboy
 			Buffer.RemoveAllTags (TitleStart, TitleEnd);
 			Buffer.ApplyTag (title_tag, TitleStart, TitleEnd);
 		}
+		
+		void OnEditorFocusOut (object sender, Gtk.FocusOutEventArgs args)
+		{
+			// TODO: Duplicated from Update(); refactor instead
+			if (editing_title) {
+				Changed ();
+				UpdateNoteTitle ();
+				editing_title = false;
+			}
+		}
 
 		// This only gets called on an explicit move, not when typing
 		void OnMarkSet (object sender, Gtk.MarkSetArgs args)
@@ -107,7 +119,7 @@ namespace Tomboy
 			Buffer.ApplyTag (title_tag, TitleStart, TitleEnd);
 
 			// NOTE: Use "(Untitled #)" for empty first lines...
-			string title = TitleStart.GetText (TitleEnd).Trim ();
+			string title = TitleStart.GetSlice (TitleEnd).Trim ();
 			if (title == string.Empty)
 				title = GetUniqueUntitled ();
 
@@ -155,6 +167,8 @@ namespace Tomboy
 				return false;
 			}
 
+			Logger.Debug (string.Format ("Renaming note from {0} to {1}",
+			                             Note.Title, title));
 			Note.Title = title;
 			return true;
 		}
@@ -378,7 +392,7 @@ namespace Tomboy
 
 		string GetUrl (Gtk.TextIter start, Gtk.TextIter end)
 		{
-			string url = start.GetText (end);
+			string url = start.GetSlice (end);
 
 			// FIXME: Needed because the file match is greedy and
 			// eats a leading space.
@@ -452,7 +466,7 @@ namespace Tomboy
 
 			Buffer.RemoveTag (url_tag, start, end);
 
-			for (Match match = regex.Match (start.GetText (end)); 
+			for (Match match = regex.Match (start.GetSlice (end)); 
 			     match.Success; 
 			     match = match.NextMatch ()) {
 				System.Text.RegularExpressions.Group group = match.Groups [1];
@@ -735,7 +749,7 @@ namespace Tomboy
 
 		void HighlightInBlock (Gtk.TextIter start, Gtk.TextIter end) 
 		{
-			ArrayList hits = Manager.TitleTrie.FindMatches (start.GetText (end));
+			ArrayList hits = Manager.TitleTrie.FindMatches (start.GetSlice (end));
 			foreach (TrieHit hit in hits) {
 				DoHighlight (hit, start, end);
 			}
